import { Event, ErrorEvent, Events } from 'hint';
import { JSONLocationFunction, ISchemaValidationError, GroupedError } from '@hint/utils-json';
import * as TypeScript from 'typescript';
/** TypeScript Configuration */
export declare type TypeScriptConfig = {
    compilerOptions: TypeScript.CompilerOptions;
    compileOnSave: boolean;
    extends: string;
    files: string[];
    include: string[];
    exclude: string[];
    typeAcquisition: TypeScript.TypeAcquisition;
};
/** Data type sent for Invalid JSON event */
export declare type TypeScriptConfigInvalidJSON = ErrorEvent;
/** Data type sent for JSON doesn't validate Schema event */
export declare type TypeScriptConfigInvalidSchema = ErrorEvent & {
    errors: ISchemaValidationError[];
    groupedErrors: GroupedError[];
    prettifiedErrors: string[];
};
/** Data type sent when the parse starts parsing */
export declare type TypeScriptConfigParseStart = Event;
/** The object emitted by the `typescript-config` parser */
export declare type TypeScriptConfigParse = Event & {
    /** The final TypeScript config after adding default values */
    config: TypeScriptConfig;
    /** Find the location of a path within the original JSON source */
    getLocation: JSONLocationFunction;
    /** The combined TypeScript config after inlining `extends` */
    mergedConfig: TypeScriptConfig;
    /** The original TypeScript config */
    originalConfig: TypeScriptConfig;
};
export declare type TypeScriptConfigExtendsError = ErrorEvent & {
    getLocation: JSONLocationFunction;
};
export declare type TypeScriptConfigEvents = Events & {
    'parse::end::typescript-config': TypeScriptConfigParse;
    'parse::error::typescript-config::extends': TypeScriptConfigExtendsError;
    'parse::error::typescript-config::json': TypeScriptConfigInvalidJSON;
    'parse::error::typescript-config::schema': TypeScriptConfigInvalidSchema;
    'parse::start::typescript-config': TypeScriptConfigParseStart;
};
//# sourceMappingURL=types.d.ts.map